@@ -146,6 +146,7 @@ require AutoLoader;
 	SQL_API_SQLTABLEPRIVILEGES
 	SQL_API_SQLTABLES
 	SQL_API_SQLTRANSACT
+	SQL_APPLICATION_CODEPAGE
 	SQL_ARD_TYPE
 	SQL_ASYNC_ENABLE
 	SQL_ASYNC_ENABLE_DEFAULT
@@ -448,6 +449,7 @@ require AutoLoader;
 	SQL_CONN_CONTEXT
 	SQL_CONN_OPT_MAX
 	SQL_CONN_OPT_MIN
+	SQL_CONNECT_CODEPAGE
 	SQL_CONVERT_BIGINT
 	SQL_CONVERT_BINARY
 	SQL_CONVERT_BIT
@@ -610,6 +612,7 @@ require AutoLoader;
 	SQL_C_UTINYINT
 	SQL_C_VARBOOKMARK
 	SQL_DATABASE_NAME
+	SQL_DATABASE_CODEPAGE
 	SQL_DATALINK
 	SQL_DATALINK_URL
 	SQL_DATA_AT_EXEC
